@@ -27,26 +27,25 @@ __all__ = [
     'Drug',
     'Experience',
     'BodySystem',
-    'today',
-    'now'
+    'Profession',
+    'PaymentMethod',
+    'Percent',
+    'Cowntry',
+    'Project',
     ]
 
 from enum import Enum 
-import csv 
 from datetime import timedelta, date, datetime
 from typing import Union
 from collections import ChainMap
 from functools import cache
 
 from metadoctor import utils
-from metadoctor import settings
 
-today = date.today
-now = datetime.now()
 
 class Variable(Enum):
-    UNDEFINED = '<undefined>'
-    MISSING = '<missing>'
+    UNDEFINED = 'Indefinido'
+    MISSING = 'Ausente'
     
     def __str__(self):
         return self.value
@@ -73,60 +72,102 @@ class BaseEnum(Enum):
             return self.value
         elif type(self.value) == int:
             return str(self.value)
-        elif type(self.value) == tuple:
-            if len(self.value) == 1:
-                return str(self.value[0])
-            else:
-                return str(self.value[1])
+        elif isinstance(self.value, (tuple, list)):
+            gen = (x for x in self.value if isinstance(x, str))
+            return next(gen)
         else:
             return str(self.value)
     
     def __repr__(self) -> str:
         return f'{type(self).__name__}.{self.name}'
     
+    
+    def __html_option__(self):
+        return f'<option value="{self.name}">{str(self)}</option>'
+    
+    
     @classmethod
-    @cache
-    def choices(cls):
-        '''member name as keyword and str of member as value'''
-        return [(e.name, str(e)) for e in cls.__members__.values()]
+    def members(cls):
+        return [e for e in cls.__members__.values()]
+    
+    @classmethod
+    def choices(cls, selected=None):
+        members = cls.members()
+        choices = []
+        for item in members:
+            if item == selected or item.name == selected or item.value == selected or str(item) == str(selected):
+                choices.append((item.name, item, True))
+            else:
+                choices.append((item.name, item, False))
+        return choices
+    
+    @classmethod
+    async def options(cls, selected=None):
+        class Option:
+            def __init__(self, value, content, selected=False):
+                self.value = value
+                self.content = content 
+                self.selected = selected 
+                
+            def __str__(self):
+                return f'<option value="{self.value}">{self.content}</option>' if self.selected == False else f'<option value="{self.value}" selected>{self.content}</option>'
+            
+        members = cls.members()
+        options = []
+        for item in members:
+            if item == selected or item.name == selected or item.value == selected:
+                options.append(Option(value=item.name, content=item.value, selected=True))
+            else:
+                options.append(Option(value=item.name, content=item.value))
+        return ''.join([str(x) for x in options])
+    
 
     @classmethod
-    @cache
     def name2member_map(cls):
         '''member name as keyword and member as value'''
-        return {e.name: e for e in cls.__members__.values()}
+        return {**{e.name: e for e in cls.members()}, ** {utils.remove_accents(e.name).lower(): e for e in cls.members()}}
     
     @classmethod
-    @cache
     def str2member_map(cls):
         '''normalized and lower str of member as keyword and member as value'''
-        return {utils.remove_accents(str(e)).lower(): e for e in cls.__members__.values()}
+        return {**{str(e): e for e in cls.members()}, **{utils.remove_accents(str(e)).lower(): e for e in cls.members()}}
     
     
     @classmethod
-    @cache
     def int2member_map(cls):
         '''int as keyword and member as value'''
         try:
-            return {int(e): e for e in cls.__members__.values()}
+            return {int(e): e for e in cls.members()}
+        except:
+            return {}
+        
+    @classmethod
+    def tuple2member_map(cls):
+        '''int as keyword and member as value'''
+        try:
+            return {tuple(e): e for e in cls.members()}
         except:
             return {}
     
     @classmethod
-    @cache
     def value2member_map(cls):
         '''member value as keyword and member as value'''
-        return {e.value: e for e in cls.__members__.values()}
+        return {**{e.value: e for e in cls.members()}, ** {utils.remove_accents(str(e.value)).lower(): e for e in cls.members()}}
+    
     
     @classmethod
-    @cache
-    def get(cls, v: Union[str, int]):
+    def chain_map(cls):
         return ChainMap(
             cls.name2member_map(), 
             cls.str2member_map(), 
+            cls.tuple2member_map(), 
             cls.value2member_map(), 
             cls.int2member_map()
-        ).get(utils.remove_accents(v).lower() if isinstance(v, str) else v)
+        )
+    
+    @classmethod
+    def get(cls, v: Union[str, int]):
+        return cls.chain_map().get(utils.remove_accents(v).lower() if isinstance(v, str) else v)
 
 
 class StrEnum(str, BaseEnum):
@@ -163,11 +204,11 @@ class Day(timedelta, BaseEnum):
     
     @classmethod
     def __date_ahead__(cls, v: int):
-        return today() + cls[str(v)].value
+        return utils.today() + cls[str(v)].value
     
     @classmethod
     def __date_ago__(cls, v: int):
-        return today() - cls[str(v)].value
+        return utils.today() - cls[str(v)].value
     
     @classmethod
     def value2member_map(cls):
@@ -249,10 +290,12 @@ class Permission(StrEnum):
     F = 'Proibido'
     U = 'Indefinido'
     
+    
 class Right(StrEnum):
     R = 'Ler'
     W = 'Escrever'
     
+    
 class Access(StrEnum):
     P = 'Público'
     U = 'Usuário'
@@ -289,7 +332,7 @@ class ActiveDrugType(TupleEnum):
     VASODILATOR = 'Vasodilatador'
 
 
-class Pharmaceutical(TupleEnum):
+class Pharmaceutical(StrEnum):
     '''Pharmaceutical: name'''
     BIOLAB = 'Biolab'
     PFIZER = 'Pfizer'
@@ -426,7 +469,6 @@ class Brand(TupleEnum):
     ARISTAB = 'Aristab', [ActiveDrug.ARIPIPRAZOLE], [(10,30),(15,30),(20,30)], DosageUnit.MG, DosageForm.TABLET, DosageUse.DOSAGE_FORM, Pharmaceutical.ACHE
     TURNOSL = 'Turno Sl', [ActiveDrug.ZOLPIDEM], [(5,30)], DosageUnit.MG, DosageForm.TABLET, DosageUse.DOSAGE_FORM, Pharmaceutical.EUROFARMA
 
-    
     @property
     def brand_name(self):
         val = self.value[0]
@@ -463,7 +505,7 @@ class Brand(TupleEnum):
     def pharmaceutical(self):
         return self.value[6].value[0]
     
-    
+
 class Drug(TupleEnum):
     _ignore_ = 'Drug brand Brand item name'
     Drug = vars()
@@ -495,7 +537,6 @@ Experience.str = lambda x: f"{x.value[1]}"
 Experience.int = lambda x: f"{x.value[0]}"
 
 
-
 class BodySystem(StrEnum):
     CAR = 'Cardiovascular'
     RES = 'Respiratório'
@@ -511,17 +552,47 @@ class BodySystem(StrEnum):
     EXC = 'Excretor'
     
     
-# @cache
-# def get_cid10data_from_csv(csv_file):
-#     data = {}
-#     with open(csv_file) as file:
-#         for item in csv.DictReader(file, fieldnames=['code', 'title']):
-#             data[item['code']] = item['title']
-#         return data 
-
-
-# class Cid10Enum(BaseEnum):
-#     _ignore_ = 'Cid10Enum key value' 
-#     Cid10Enum = vars()
-#     for key, value in get_cid10data_from_csv(settings.CID10_FILE).items():
-#         Cid10Enum[key] = value
\ No newline at end of file
+class PaymentMethod(StrEnum):
+    CC = 'Cartão de Crédito'
+    CD = 'Cartão de Débito'
+    TR = 'Transferência Bancária'
+    DI = 'Dinheiro'
+    CH = 'Cheque'
+    PX = 'Pix'
+    
+    
+class Profession(StrEnum):
+    MED = 'Medicina'
+    PSY = 'Psicologia'
+    FIS = 'Fisioterapia'
+    NUR = 'Enfermagem'
+    FON = 'Fonoaudiologia'
+    OCP = 'Terapia Ocupacional'
+    
+    
+class Percent(BaseEnum):
+    _ignore_ = 'Percent val'
+    Percent = vars()
+    for val in range(101):
+        Percent[f'{val}'] = f'{val}%', val/100
+        
+    def __float__(self):
+        return self.value[1]
+    
+    def __str__(self):
+        return self.value[0]
+    
+    
+class Cowntry(BaseEnum):
+    BRA = 'Brasil'
+    USA = 'Estados Unidos'
+    QAT = 'Qatar'
+    POR = 'Portugal'
+    ARG = 'Argentina'
+    
+    
+class Project(StrEnum):
+    BASE = 'base'
+    LOG = 'log'
+    CLIENT = 'client'
+    USER = 'user'
