@@ -5,10 +5,8 @@ __all__ = [
 import os
 from collections import ChainMap
 from starlette.config import Config
-from starlette.datastructures import Secret, CommaSeparatedStrings
-from starlette.staticfiles import StaticFiles
-from starlette.templating import Jinja2Templates
-from dataclasses import dataclass, field
+from starlette.datastructures import Secret
+from dataclasses import dataclass
 
 
 
@@ -25,8 +23,6 @@ except:
 @dataclass
 class Settings:
     config: Config = config
-    static: StaticFiles = static 
-    jinja: Jinja2Templates = jinja
         
     def __post_init__(self):
         self.chain = ChainMap({}, {k: Secret(v) for k,v in vars(self.config)['file_values'].items()})
